==> dde-printer_0.9.2.orig.tar.xz: dde-printer-0.9.2/src/Deamon/translations/dde-printer-helper_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="554"/>
        <source>URI and driver do not match.</source>
        <translation>L&apos;URI et le pilote ne correspondent pas.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="556"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>Installer d&apos;abord hplip et redémarrer l&apos;application pour réinstaller le pilote.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="564"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>Veuillez sélectionner un pilote hplip et réessayer.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="577"/>
        <source>URI can&apos;t be empty</source>
        <translation>L&apos;URI ne peut pas être vide</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="584"/>
        <source> not found</source>
        <translation>non trouvé</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="307"/>
        <source>Check printer settings</source>
        <translation>Vérifier les paramètres de l&apos;imprimante</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="316"/>
        <source>Checking printer settings...</source>
        <translation>Vérification des paramètres de l&apos;imprimante en cours...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="319"/>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="329"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>Impossible d&apos;obtenir les attributs de l&apos;imprimante, erreur:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="337"/>
        <source>%1 is disabled</source>
        <translation>%1 est désactivé</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="346"/>
        <source>is not accepting jobs</source>
        <translation>n&apos;accepte pas les travaux</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="351"/>
        <source>Printer settings are ok</source>
        <translation>Les paramètres de l&apos;imprimante sont corrects</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="212"/>
        <source>Check printer connection</source>
        <translation>Vérifier la connexion de l&apos;imprimante</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="224"/>
        <source>Checking printer connection...</source>
        <translation>Vérification de la connexion de l&apos;imprimante...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="227"/>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="264"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>Impossible de se connecter à l&apos;imprimante, erreur: %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="272"/>
        <source> is not connected, URI: </source>
        <translation>n&apos;est pas connecté, URI:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="281"/>
        <source>%1 does not exist</source>
        <translation>%1 n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="290"/>
        <source>Cannot connect to the printer</source>
        <translation>Impossible de se connecter à l&apos;imprimante</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="296"/>
        <source>The connection is valid</source>
        <translation>La connexion est valide</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="110"/>
        <source>Check CUPS server</source>
        <translation>Vérifier le serveur CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="116"/>
        <source>Checking CUPS server...</source>
        <translation>Vérification du serveur CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="118"/>
        <source>CUPS server is invalid</source>
        <translation>Le serveur CUPS n&apos;est pas valide</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="123"/>
        <source>CUPS server is valid</source>
        <translation>Le serveur CUPS est valide</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="141"/>
        <source>Checking driver...</source>
        <translation>Vérification du pilote...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="144"/>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="152"/>
        <source>PPD file %1 not found</source>
        <translation>Fichier PPD %1 introuvable</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="162"/>
        <source>The driver is damaged</source>
        <translation>Le pilote est endommagé</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="178"/>
        <source>Driver filter %1 not found</source>
        <translation>Filtre du pilote %1 introuvable</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="190"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 n&apos;est pas installé, impossible d&apos;imprimer maintenant</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="196"/>
        <source>Driver is valid</source>
        <translation>Le pilote n&apos;est pas valide</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="202"/>
        <source>Check driver</source>
        <translation>Vérifier le pilote</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="77"/>
        <source>Queuing</source>
        <translation>File d&apos;attente</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="78"/>
        <source>Paused</source>
        <translation>En pause</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="79"/>
        <source>Printing</source>
        <translation>Impression en cours</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="80"/>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="81"/>
        <source>Canceled</source>
        <translation>Annulé</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="82"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="83"/>
        <source>Completed</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="338"/>
        <source>%1 timed out, reason: %2</source>
        <translation>%1 est dépassé, raison : %2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="352"/>
        <source>%1 printed successfully, please take away the paper in time!</source>
        <translation>%1 imprimé avec succès</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="354"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1 %2, raison : %3</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="906"/>
        <source>EveryWhere driver</source>
        <translation>Tout pilote</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="371"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>Impossible de trouver la solution du pilote : %1, erreur : %2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="382"/>
        <source>The solution is invalid</source>
        <translation>La solution n&apos;est pas valide</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="252"/>
        <source>is invalid</source>
        <translation>n&apos;est pas valide</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="281"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>Impossible d&apos;installer le pilote en appelant l&apos;interface dbus</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="326"/>
        <source>Failed to install %1</source>
        <translation>Impossible d&apos;installer %1</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>non trouvé</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="372"/>
        <source>Check test page printing</source>
        <translation>Vérifier l&apos;impression de la page de test</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="426"/>
        <source>Printing test page...</source>
        <translation>Impression de la page de test...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../Common/common.cpp" line="152"/>
        <source> not found, please ask the administrator for help</source>
        <translation>introuvable, veuillez demander de l&apos;aide à l&apos;administrateur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>Gestionnaire d&apos;impression</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>Print Manager est un outil de gestion d&apos;imprimante qui prend en charge l&apos;ajout et la suppression d&apos;imprimantes, la gestion des travaux d&apos;impression, etc.</translation>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="257"/>
        <source>Configuring the printer %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="303"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="307"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-printer_0.9.13.orig.tar.xz: dde-printer-0.9.13/src/Deamon/translations/dde-printer-helper_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="552"/>
        <source>URI and driver do not match.</source>
        <translation>L&apos;URI et le pilote ne correspondent pas.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="554"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>Installez d&apos;abord hplip et redémarrez l&apos;application pour réinstaller le pilote.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="562"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>Veuillez sélectionner un pilote hplip et réessayer.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="575"/>
        <source>URI can&apos;t be empty</source>
        <translation>L&apos;URI ne peut pas être vide</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="582"/>
        <source> not found</source>
        <translation>non trouvé</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>Vérifier les paramètres de l&apos;imprimante</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>Vérification des paramètres de l&apos;imprimante en cours...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>Impossible d&apos;obtenir les attributs de l&apos;imprimante, erreur: </translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1 est désactivé</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>n&apos;accepte pas les travaux</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>Les paramètres de l&apos;imprimante sont corrects</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>Vérifier la connexion de l&apos;imprimante</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>Vérification de la connexion de l&apos;imprimante...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>Impossible de se connecter à l&apos;imprimante, erreur: %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation>n&apos;est pas connecté, URI: </translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>Impossible de se connecter à l&apos;imprimante</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>La connexion est valide</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>Vérifier le serveur CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>Vérification du serveur CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>Le serveur CUPS n&apos;est pas valide</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>Le serveur CUPS est valide</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>Vérification du pilote...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>Fichier PPD %1 introuvable</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>Le pilote est endommagé</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>Filtre du pilote %1 introuvable</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 n&apos;est pas installé, impossible d&apos;imprimer maintenant</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>Le pilote est valide</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>Vérifier le pilote</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="77"/>
        <source>Queuing</source>
        <translation>File d&apos;attente</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="78"/>
        <source>Paused</source>
        <translation>En pause</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="79"/>
        <source>Printing</source>
        <translation>Impression en cours</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="80"/>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="81"/>
        <source>Canceled</source>
        <translation>Annulé</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="82"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="83"/>
        <source>Completed</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="338"/>
        <source>%1 timed out, reason: %2</source>
        <translation>%1 est dépassé, raison : %2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="352"/>
        <source>%1 has been sent to the printer, please take away the paper in time!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="354"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1 %2, raison : %3</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1022"/>
        <source>EveryWhere driver</source>
        <translation>Tout pilote</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="372"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>Impossible de trouver la solution du pilote : %1, erreur : %2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="383"/>
        <source>The solution is invalid</source>
        <translation>La solution n&apos;est pas valide</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="250"/>
        <source>is invalid</source>
        <translation>n&apos;est pas valide</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="279"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>Impossible d&apos;installer le pilote en appelant l&apos;interface dbus</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="324"/>
        <source>Failed to install %1</source>
        <translation>Impossible d&apos;installer %1</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>non trouvé</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>Vérifier l&apos;impression de la page de test</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>Impression de la page de test...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source> not found, please ask the administrator for help</source>
        <translation>introuvable, veuillez demander de l&apos;aide à l&apos;administrateur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>Gestionnaire d&apos;impression</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>Print Manager est un outil de gestion d&apos;imprimante qui prend en charge l&apos;ajout et la suppression d&apos;imprimantes, la gestion des travaux d&apos;impression, etc.</translation>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="256"/>
        <source>Configuring the printer %1 ...</source>
        <translation>Configuration de l&apos;imprimante %1...</translation>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="302"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation>Configuration réussie. Cliquez pour afficher %1.</translation>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="306"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation>La configuration a échoué. Cliquez pour ajouter l&apos;imprimante %1.</translation>
    </message>
</context>
</TS>
